#include <ESP8266WiFi.h>
#include <OneWire.h>
#include <DallasTemperature.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <Fonts/FreeSans18pt7b.h>

#define ONE_WIRE_BUS D3
#define OLED_RESET 0  // GPIO0

Adafruit_SSD1306 OLED(OLED_RESET);
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature DS18B20(&oneWire);
WiFiServer server(80);
char temperatureCString[6];
float temp;
float tempC;
const char* ssid = "home1";
const char* password = "RichieBlackmore";

void setup()
{
 Serial.begin(115200);
 delay(10);
 DS18B20.begin(); 
 OLED.begin(SSD1306_SWITCHCAPVCC, 0x3C);
 Serial.println();
 Serial.print("Connecting to ");
 Serial.println(ssid);
 WiFi.begin(ssid, password);
 while (WiFi.status() != WL_CONNECTED)
 {
  delay(500);
  Serial.print(".");
 }
 Serial.println("");
 Serial.println("WiFi connected");
 server.begin();
 Serial.println("Web server running. Waiting for the Wemos D1 mini IP...");
 delay(3000);
 Serial.println(WiFi.localIP());
}

void loop()
{
 getTemperature();
 setDisplay();
 setWebpage();
}

void getTemperature()
{
 do
 {
  DS18B20.requestTemperatures(); 
  temp = DS18B20.getTempCByIndex(0);
  delay(200);
  tempC = temp - 0; // Korrekturwert
  dtostrf(tempC, 2, 1, temperatureCString);
  delay(800);
 } while (tempC == 85.0 || tempC == (-127.0));
}

void setDisplay()
{
  do
  {
   OLED.setFont(&FreeSans18pt7b);
   OLED.cp437(true);
   OLED.setTextWrap(false);
   OLED.setTextSize(1);
   OLED.setTextColor(WHITE);
   OLED.setCursor(8,28);
   OLED.clearDisplay();
   OLED.print(temperatureCString);
   OLED.print("  ");
   OLED.drawCircle(88, 6, 3, WHITE); // degree symbol
   OLED.println("C");
   OLED.display();
   delay(1000);
  }
  while (tempC == 85.0 || tempC == (-127.0));
}

void setWebpage()
{
 WiFiClient client = server.available();
 if (client)
 {
  Serial.println("New client");
  boolean blank_line = true;
  while (client.connected())
  {
   if (client.available())
   {
    char c = client.read();  
    if (c == '\n' && blank_line)
    {
     getTemperature();
     client.println("HTTP/1.1 200 OK");
     client.println("Content-Type: text/html");
     client.println("Connection: close");
     client.println();
     client.println("<!DOCTYPE HTML>");
     client.println("<html>");
     client.println("<head><meta http-equiv=refresh content=15></head><body bgcolor=33363B><center><h1><font face=Ubuntu color=FFFFFF>Temperatur in Celsius: ");
     client.println(temperatureCString);
     client.println("&deg;C</font></h1></center></body></html>"); 
     delay(1);
     client.stop();
     Serial.println("Client disconnected.");
     break;
    }
    if (c == '\n')
    {
     blank_line = true;
    }
    else if (c != '\r')
    {
     blank_line = false;
    }
   }
  }
 }
}